[chronojump/michrolab] Encoder, graph.R. Fixed lack of Smoothings on singleFile ec (powerbars, cross, paint (1 or more reps



commit 756c31a6c058d94f70a1dd7abc7e0d8f3df65a1d
Author: Xavier de Blas <xaviblas gmail com>
Date:   Wed Jun 8 12:02:07 2022 +0200

    Encoder, graph.R. Fixed lack of Smoothings on singleFile ec (powerbars, cross, paint (1 or more reps)

 encoder/graph.R | 18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)
---
diff --git a/encoder/graph.R b/encoder/graph.R
index 5203dbb36..e869010a6 100644
--- a/encoder/graph.R
+++ b/encoder/graph.R
@@ -3117,15 +3117,15 @@ doProcess <- function(options)
                                #SmoothingsEC[i] = 0
                #}
                #else {
-                       #singleCurveNum <- -1
-                       #if(op$Analysis == "single" && op$Jump > 0)
-                               #singleCurveNum <- op$Jump
-                       #SmoothingsEC <- findSmoothingsEC(
-                               #singleFile, displacement, curves, singleCurveNum, op$Eccon, op$SmoothingOneC,
-                               #op$EncoderConfigurationName, op$diameter, op$inertiaMomentum, op$gearedDown
-                       #) #second row is needed for singleFile (signal)
+                       singleCurveNum <- -1
+                       if(op$Analysis == "single" && op$Jump > 0)
+                               singleCurveNum <- op$Jump
+                       SmoothingsEC <- findSmoothingsEC(
+                               singleFile, displacement, curves, singleCurveNum, op$Eccon, op$SmoothingOneC,
+                               op$EncoderConfigurationName, op$diameter, op$inertiaMomentum, op$gearedDown
+                       ) #second row is needed for singleFile (signal)
                #}
-               #print(c("SmoothingsEC:",SmoothingsEC))
+               print(c("SmoothingsEC:",SmoothingsEC))
 
                 if(curvesPlot) {
                         #/10 mm -> cm
@@ -3262,7 +3262,7 @@ doProcess <- function(options)
                                           FALSE                #show all the repetition, not only ground 
phase on ecc
                         ) 
                         
                         #smoothing for displamenet
                         smoothingTemp = 0
                         if(repOp$eccon == "c" || repOp$eccon == "e")
                                 smoothingTemp = op$SmoothingOneC
@@ -3262,7 +3262,7 @@ doProcess <- function(options)
                         ) 
                         
-                        #smoothing for displamenet
+                        #smoothing for displacement
                         smoothingTemp = 0
                         if(repOp$eccon == "c" || repOp$eccon == "e")


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]